import type { NextApiRequest, NextApiResponse } from "next"
import sendError from "../../lib/backend/components/sendError"
import getTokenFromCookie from "../../lib/backend/components/getTokenFromCookie"
import checkTokenIsValid from "../../lib/backend/components/checkTokenIsValid"
import getTokenDB from "../../lib/backend/components/getTokenDB"
import getPlayerByIdDB from "../../lib/backend/components/getPlayerByIdDB"
import sendResponse from "../../lib/backend/components/sendResponse"

interface Data {
  token: string
}

export default async function auth(
  req: NextApiRequest,
  res: NextApiResponse<Data>
) {
  const context = { req, res }

  getTokenFromCookie(context, (refreshToken) => {
    checkTokenIsValid(context, refreshToken, (token) => {
      getTokenDB(context, token, (tokenDB) => {
        getPlayerByIdDB(context, tokenDB, (player) => {
          sendResponse(context, {
            message: "loginCheck -> true : " + player.id,
            type: ["debug", "infoCyan"],
          })
        })
      })
    })
  }).catch((err) => sendError(context, err))
}
