import type { NextApiRequest, NextApiResponse } from "next"
import checkTokenIsValid from "../../lib/backend/components/checkTokenIsValid"
import sendResponse from "../../lib/backend/components/sendResponse"
import sendError from "../../lib/backend/components/sendError"
import { deleteCookie } from "cookies-next"
import getTokenDB from "../../lib/backend/components/getTokenDB"
import getTokenFromCookie from "../../lib/backend/components/getTokenFromCookie"

interface Data {
  loggedOut: boolean
}

export default async function logout(
  req: NextApiRequest,
  res: NextApiResponse<any>
) {
  const context = { req, res }

  return getTokenFromCookie(context, (refreshToken) => {
    checkTokenIsValid(context, refreshToken, (token) => {
      getTokenDB(context, token, (tokenDB) => {
        // Set login cookie
        deleteCookie("token", { req, res })

        sendResponse(context, {
          message: "User of Token " + tokenDB.id + " logged out.",
          body: { loggedOut: true },
          type: ["debug", "infoCyan"],
        })
      })
    })
  }).catch((err) => sendError(context, err))
}
