import { NextApiRequest, NextApiResponse } from "next"
import getPlayerByNameDB from "../../lib/backend/components/getPlayerByNameDB"
import checkPasswordIsValid from "../../lib/backend/components/checkPasswordIsValid"
import sendResponse from "../../lib/backend/components/sendResponse"
import prisma from "../../lib/prisma"
import sendError from "../../lib/backend/components/sendError"
import getUserFromBody from "../../lib/backend/components/getUserFromBody"

interface Data {
  loggedIn: boolean
}

export default async function remove(
  req: NextApiRequest,
  res: NextApiResponse<Data>
) {
  const context = { req, res }

  return getUserFromBody(context, (username, password) =>
    getPlayerByNameDB(context, username, (player) => {
      checkPasswordIsValid(context, player, password, () => {
        prisma.player.update({
          where: {
            id: player.id,
          },
          data: {
            deleted: true,
            username: null,
            email: null,
            passwordHash: null,
          },
        })
        sendResponse(context, {
          message: "User successfully deleted: " + player.id,
          type: ["debug", "infoCyan"],
        })
      })
    })
  ).catch((err) => sendError(context, err))
}
